@@ -120,7 +120,8 @@ class estimator():
             #self.model_path = 'trained_states/{}d/{}d_{}.ckpt'.format(self.dim, self.dim, self.num_point)
             model_resources = files('deep_density_estimation')
             self.model_path = as_file(model_resources / 'trained_states' / '{}d'.format(self.dim) / '{}d_{}.ckpt'.format(self.dim, self.num_point))
-            assert os.path.exists(self.model_path+'.index'), 'could not find model {}'.format(self.model_path)
+            print(self.model_path)
+            #assert os.path.exists(self.model_path+'.index'), 'could not find model {}'.format(self.model_path)
         
         self.batch_size = batch_size
         
